@@ -252,7 +252,38 @@ class Api(snappi.Api):
         self._running_config = self._config
         self._apply_change()
         with Timer(self, "Start interfaces"):
-            self._start_interface()
+            # Start all protocols is workaround for pCPU crash reported by
+            # Microsoft, need to revert once fix is available for pCPU crash
+            if self._protocols_exists():
+                self._start_interface()
+            else:
+                if len(self._ixnetwork.Topology.find()) > 0:
+                    self._ixnetwork.StartAllProtocols()
+
+    def _protocols_exists(self):
+        total_dev = len(self._ixnetwork.GetTopologyStatus())
+        topos = self._ixnetwork.Topology.find()
+        ethv4v6_dev_count = 0
+        if len(topos) > 0:
+            dgs = topos.DeviceGroup.find()
+            if len(dgs) > 0:
+                eth_dev = len(self._ixnetwork.Topology.find()
+                              .DeviceGroup.find()
+                              .Ethernet.find())
+                ethv4v6_dev_count = ethv4v6_dev_count + eth_dev
+                if eth_dev > 0:
+                    v4_dev = len(self._ixnetwork.Topology.find()
+                                 .DeviceGroup.find()
+                                 .Ethernet.find().Ipv4.find())
+                    ethv4v6_dev_count = ethv4v6_dev_count + v4_dev
+                    v6_dev = len(self._ixnetwork.Topology.find()
+                                 .DeviceGroup.find()
+                                 .Ethernet.find().Ipv6.find())
+                    ethv4v6_dev_count = ethv4v6_dev_count + v6_dev
+        if (total_dev > ethv4v6_dev_count):
+            return True
+        else:
+            return False
 
     def set_protocol_state(self, payload):
         """Set the transmit state of flows"""
@@ -659,9 +690,10 @@ class Api(snappi.Api):
                 if port.location is None:
                     continue
                 if ";" in port.location:
-                    (_, card, port_info) = port.location.split(";")
-                    port_info = "{}.{}".format(card, port_info)
+                    # Ex: 10.36.70.66;localuhd;1 or 10.36.70.66;localuhd;17.1
+                    (_, _, port_info) = port.location.split(";")
                 elif "/" in port.location:
+                    # Ex: localuhd/1
                     (_, port_info) = port.location.split("/")
                 else:
                     raise SnappiIxnException(400, "port location is not valid")
