@@ -743,7 +743,14 @@ class TrafficItem(CustomField):
                 self._configure_rate(
                     tr_item["configElement"], flow.get("rate", True)
                 )
-                hl_stream_count = len(ixn_traffic_item[i]["highLevelStream"])
+                # TODO: ixNetwork is not creating flow groups for vxlan, remove
+                # hard coding of setting to 1 once the issue is fixed in ixn
+                if "highLevelStream" not in ixn_traffic_item[i].keys():
+                    hl_stream_count = 1
+                else:
+                    hl_stream_count = len(
+                        ixn_traffic_item[i]["highLevelStream"]
+                    )
                 self._configure_duration(
                     tr_item["configElement"],
                     hl_stream_count,
@@ -918,8 +925,28 @@ class TrafficItem(CustomField):
     def _getUhdHeader(self, header=None):
         if self.isUhd is True and header == "ethernetpause":
             return header + "UHD"
+        elif header == "ethernetpause":
+            # This is to support 9.20 globalpause header
+            if "globalPause" in self._getProtocolTemplatelist():
+                return header + "UHD"
         return header
 
+    def _getProtocolTemplatelist(self):
+        filter = [{"property": "name", "regex": ".*"}]
+        parent = "/traffic"
+        child = "protocolTemplate"
+        properties = ["displayName", "stackTypeId"]
+        ixn = self._api.assistant._ixnetwork
+
+        url, payload = self._get_search_payload(
+            parent=parent, child=child, properties=properties, filters=filter
+        )
+        stack_ids = []
+        result = ixn._connection._execute(url, payload)
+        for item in result[0].get("protocolTemplate", []):
+            stack_ids.append(item.get("stackTypeId"))
+        return stack_ids
+
     def _configure_stack_fields(
         self, ixn_fields, snappi_header, stacks, is_raw_traffic=False
     ):
@@ -983,6 +1010,7 @@ class TrafficItem(CustomField):
             "decrement": "decrement",
             "auto": "auto",
             "generated": "auto",
+            "custom": "singleValue"
         }
 
         def get_value(field_value):
@@ -1025,6 +1053,9 @@ class TrafficItem(CustomField):
                 # TODO currently added some dummy value for bad generated value
                 # Need to add some logic to generate bad value
                 field_json["value"] = "0001"
+        if choice == "custom":
+            value = snappi_field.get(choice)
+            field_json[ixn_pattern[choice]] = value
         field_json["activeFieldChoice"] = active_field
         field_json["auto"] = True if choice == "auto" else False
         return
